@@ -8,4 +8,6 @@ task1_id = '708b5625-63e0-4aaa-b941-97bb802f4954'  # Complete the installation o
 if 'milestone_3.txt' in os.listdir('.'):
     errors = get_errors_fails('milestone_3.txt')
     if len(errors) != 0:
-        mark_incomplete(task1_id, errors['test_requirements_presence'])
\ No newline at end of file
+        mark_incomplete(task1_id, errors['test_requirements_presence'])
+    else:
+        mark_complete(task1_id)
\ No newline at end of file
